#include "webapp-info.h"
#include <string.h>

struct _WebappInfo {
  gchar *package_name;
  gchar *application_name;

  GPtrArray *urls;
};

WebappInfo *
webapp_info_new (const gchar *package_name)
{
  WebappInfo *info;
  
  info = g_malloc0(sizeof (WebappInfo));
  info->package_name = g_strdup (package_name);
  info->urls = g_ptr_array_new_full (3, g_free);
  
  info->application_name = NULL;
  
  return info;
}

void
webapp_info_free (WebappInfo *info)
{
  g_ptr_array_free (info->urls, TRUE);
  g_free (info->package_name);
  g_free (info->application_name);
  g_free (info);
}

const gchar *
webapp_info_get_package_name (WebappInfo *info)
{
  return info->package_name;
}

const gchar *
webapp_info_get_application_name (WebappInfo *info)
{
  return info->application_name;
}

void
webapp_info_set_application_name (WebappInfo *info, const gchar *application_name)
{
  g_return_if_fail (info->application_name == NULL);
  
  info->application_name = g_strdup (application_name);
}

void
webapp_info_add_url (WebappInfo *info, const gchar *url)
{
  g_ptr_array_add (info->urls, g_strdup (url));
}

GPtrArray *
webapp_info_get_urls (WebappInfo *info)
{
  return info->urls;
}

gboolean
webapp_info_has_urls (WebappInfo *info)
{
  return ((gchar *)g_ptr_array_index(info->urls, 0) != NULL);
}

gboolean
webapp_info_verify (WebappInfo *info)
{
  if (info->package_name == NULL)
    {
      return FALSE;
    }
  if (g_str_has_prefix (info->package_name, "unity-webapps") == FALSE)
    {
      return FALSE;
    }
  if (info->application_name == NULL)
    {
      return FALSE;
    }
  if (strlen (info->application_name) == 0)
    {
      return FALSE;
    }
  if (webapp_info_has_urls (info) == FALSE)
    {
      return FALSE;
    }
  return TRUE;
}
